@@ -80,7 +80,7 @@ def update_perms_and_save(request, form, instance, **kwargs):
     # save again for indexing purposes
     # TODO: find a better solution, saving twice kinda sux
     instance.save(**kwargs)
-    
+
     # assign the permission to the medial files
     assign_files_perms(instance)
 
@@ -213,11 +213,13 @@ def has_view_perm(user, perm, obj=None):
 def get_query_filters(user, perm, **kwargs):
     """
     Method to generate search query filters for different user types.
+    * super_perm kwarg simulates admin behavior.
     """
     # impersonation
     user = getattr(user, 'impersonated_user', user)
 
     perms_field = kwargs.get('perms_field', True)
+    super_perm = kwargs.get('super_perm', False)
 
     group_perm = Q()
     group_q = Q()
